#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hls-module-name-plugin
version:              1.0.0.0
visibility:           public
id:                   hls-module-name-plugin-1.0.0.0-KRH1pYtEAGh7bUjfgLdo2M
key:                  hls-module-name-plugin-1.0.0.0-KRH1pYtEAGh7bUjfgLdo2M
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           alan.zimm@gmail.com
author:               The Haskell IDE Team
synopsis:             Module name plugin for Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  795ef308ca91218f951b79f51edb3c0b
exposed:              True
exposed-modules:      Ide.Plugin.ModuleName
import-dirs:
    /usr/lib/ghc-8.10.5/site-local/hls-module-name-plugin-1.0.0.0

library-dirs:
    /usr/lib/ghc-8.10.5/site-local/hls-module-name-plugin-1.0.0.0

dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/i386-linux-ghc-8.10.5/hls-module-name-plugin-1.0.0.0

hs-libraries:         HShls-module-name-plugin-1.0.0.0-KRH1pYtEAGh7bUjfgLdo2M
depends:
    aeson-1.5.6.0-CVfeYccFVpdCde0UrZZZdZ base-4.14.2.0
    directory-1.3.6.0 filepath-1.4.2.1
    ghcide-1.4.0.1-5stW1V6MhVBGeCRHZSaIfO
    hls-plugin-api-1.1.0.2-6o7hY0E5YQuCD8G4Bf3t3o
    lsp-1.2.0.0-JYjHpvPu1SW4k7gGYBb5ES text-1.2.4.1
    transformers-0.5.6.2
    unordered-containers-0.2.14.0-JpdjDmlqBJN4PAu3jIj4Ya

haddock-interfaces:
    /usr/share/doc/haskell-hls-module-name-plugin/html/hls-module-name-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-module-name-plugin/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

